ratneshpy
=========

.. image:: https://img.shields.io/pypi/v/ratneshpy.svg
    :target: https://pypi.python.org/pypi/ratneshpy
    :alt: Latest PyPI version

.. image:: https://www.travis-ci.org/imratnesh/ratneshpy.png
   :target: https://www.travis-ci.org/imratnesh/ratneshpy
   :alt: Latest Travis CI build status

Ratnesh python package for work

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`ratneshpy` was written by `Ratnesh Kushwaha <rat.kush@gmail.com>`_.
